TimelineEventDisplay class

Constructors

TimelineEventDisplay({required Widget child, Widget? indicator, double? indicatorSize, bool forceLineDrawing = false, IndicatorPosition? anchor, Offset indicatorOffset = const Offset(0, 0)})

Properties

anchor → IndicatorPosition?
anchor overrides the default IndicatorPosition
final
child → Widget
final
forceLineDrawing → bool
enables indicator line drawing even no indicator is passed.
final
hashCode → int
The hash code for this object.
no setterinherited
hasIndicator → bool
no setter
indicator → Widget?
final
indicatorOffset → Offset
final
indicatorSize → double?
if not provided, use the default indicator size
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited