TimelineThemeData class

TimelineThemeData is passed through TimelineTheme, works like general flutter theme object.

Mixed-in types

Constructors

TimelineThemeData({double gutterSpacing = 12.0, double itemGap = 24.0, double lineGap = 0.0, double strokeWidth = 4.0, StrokeCap strokeCap = StrokeCap.butt, Color lineColor = Colors.lightBlueAccent, PaintingStyle style = PaintingStyle.stroke, IndicatorPosition indicatorPosition = IndicatorPosition.center})
TimelineThemeData.fallback()
Creates an timeline them with some reasonable default values.
const

Properties

gutterSpacing → double
final
hashCode → int
The hash code for this object.
no setterinherited
indicatorPosition → IndicatorPosition
the position of the indicator. this affects the placing of the indicator, and following line measurement
final
itemGap → double
final
lineColor → Color
final
lineGap → double
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
strokeCap → StrokeCap
final
strokeWidth → double
final
style → PaintingStyle
final

Methods

copyWith({Color? lineColor, StrokeCap? strokeCap, double? strokeWidth}) → TimelineThemeData
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolve(BuildContext context) → TimelineThemeData
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited